@@ -140,7 +140,7 @@ void FormWindow::init()
   unclippedPainter = 0;
   widgetPressed = false;
   drawRubber = false;
-  setFocusPolicy(TQ_ClickFocus);
+  setFocusPolicy(TQWidget::ClickFocus);
   sizePreviewLabel = 0;
   checkSelectionsTimer = new TQTimer(this, "checkSelectionsTimer");
   connect(checkSelectionsTimer, TQT_SIGNAL(timeout()),
@@ -362,7 +362,7 @@ void FormWindow::insertWidget()
       TQObject *o = it.current();
       ++it;
       if (o->isWidgetType() && ((TQWidget*)o)->isVisibleTo(this) &&
-          insertedWidgets.find((TQWidget*)o) && TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(w))
+          insertedWidgets.find((TQWidget*)o) && o != w)
       {
         TQRect r2(((TQWidget*)o)->pos(), ((TQWidget*)o)->size());
         if (r.contains(r2))
@@ -798,7 +798,7 @@ void FormWindow::handleMouseMove(TQMouseEvent *e, TQWidget *w)
     if (newReceiver && (newReceiver->inherits("TQLayoutWidget")
         || newReceiver->inherits("Spacer")))
       newReceiver = (TQWidget*)connectReceiver;
-    drawRecRect = TQT_BASE_OBJECT(newReceiver) != TQT_BASE_OBJECT(connectReceiver);
+    drawRecRect = newReceiver != connectReceiver;
     currentConnectPos = mapFromGlobal(e->globalPos());
     if (newReceiver && (isMainContainer(TQT_TQOBJECT(newReceiver))
         || insertedWidgets.find(newReceiver)) && !isCentralWidget(TQT_TQOBJECT(newReceiver)))
@@ -1500,7 +1500,7 @@ void FormWindow::invalidCheckedSelections()
 
 void FormWindow::checkPreviewGeometry(TQRect & r)
 {
-  if (TQT_TQRECT_OBJECT(rect()).contains(r))
+  if (rect().contains(r))
     return;
   if (r.left() < rect().left())
     r.moveTopLeft(TQPoint(0, r.top()));
@@ -1695,7 +1695,7 @@ void FormWindow::showOrderIndicators()
     {
       TQWidget *w = (TQWidget *) o;
       if (w->isVisibleTo(w->parentWidget()) &&
-          insertedWidgets[(void *) w] && w->focusPolicy() != TQ_NoFocus)
+          insertedWidgets[(void *) w] && w->focusPolicy() != TQWidget::NoFocus)
       {
         OrderIndicator *ind = new OrderIndicator(order++, w, this);
         orderIndicators.append(ind);
@@ -2274,7 +2274,7 @@ bool FormWindow::unify(TQObject *w, TQString &s, bool changeIt)
     int num  = 1;
     TQPtrDictIterator<TQWidget> it(insertedWidgets);
     for (; it.current();)
-      if (TQT_BASE_OBJECT(it.current()) != TQT_BASE_OBJECT(w) && !qstrcmp(it.current()->name(), s.latin1()))
+      if (it.current() != w && !qstrcmp(it.current()->name(), s.latin1()))
       {
         found = true;
         if (!changeIt)
@@ -2444,7 +2444,7 @@ TQWidget *FormWindow::containerAt(const TQPoint &pos, TQWidget *notParentOf)
   TQWidget *container = 0;
   int depth = -1;
   TQWidgetList selected = selectedWidgets();
-  if (TQT_TQRECT_OBJECT(rect()).contains(mapFromGlobal(pos)))
+  if (rect().contains(mapFromGlobal(pos)))
   {
     container = mainContainer();
     depth = widgetDepth(container);
@@ -2467,7 +2467,7 @@ TQWidget *FormWindow::containerAt(const TQPoint &pos, TQWidget *notParentOf)
     TQWidget *w = it.current();
     while (w && !w->isTopLevel())
     {
-      if (!TQT_TQRECT_OBJECT(w->rect()).contains((w->mapFromGlobal(pos))))
+      if (!w->rect().contains((w->mapFromGlobal(pos))))
         break;
       w = w->parentWidget();
     }
@@ -2489,7 +2489,7 @@ TQWidget *FormWindow::containerAt(const TQPoint &pos, TQWidget *notParentOf)
 
 bool FormWindow::isMainContainer(TQObject *w) const
 {
-  return w && w->isWidgetType() && (TQT_BASE_OBJECT(w) == this || TQT_BASE_OBJECT(w) == TQT_BASE_OBJECT(mainContainer()));
+  return w && w->isWidgetType() && (w == this || w == mainContainer());
 }
 
 void FormWindow::setMainContainer(TQWidget *w)
@@ -2497,7 +2497,7 @@ void FormWindow::setMainContainer(TQWidget *w)
   bool resetPropertyWidget = isMainContainer(propertyWidget);
   if (mContainer)
     insertedWidgets.remove(mContainer);
-  if (TQT_BASE_OBJECT(propertyWidget) == TQT_BASE_OBJECT(mContainer))
+  if (propertyWidget == mContainer)
     propertyWidget = 0;
   delete mContainer;
   mContainer = w;
@@ -2567,7 +2567,7 @@ bool FormWindow::isCentralWidget(TQObject *w) const
 {
   if (!mainContainer()->inherits("TQMainWindow"))
     return false;
-  return TQT_BASE_OBJECT(w) == TQT_BASE_OBJECT(((TQMainWindow*)mainContainer())->centralWidget());
+  return w == ((TQMainWindow*)mainContainer())->centralWidget();
 }
 
 TQObject *FormWindow::connectableObject(TQObject *w, TQObject *)
