@@ -19,10 +19,6 @@
 
 #include "mainwindow.h"
 
-#ifdef QT_NO_SQL
-#define TQT_NO_SQL
-#endif // QT_NO_SQL
-
 #include <tqapplication.h>
 #include <tqclipboard.h>
 #include <tqfileinfo.h>
@@ -480,14 +476,6 @@ void MainWindow::setupRunActions()
   connect(this, TQT_SIGNAL(hasActiveForm(bool)), a, TQT_SLOT(setEnabled(bool)));
   a->plug(fileTb);
   a->plug(menu);
-  // add KDE4 executor
-
-  TDEAction* b = new TDEAction(i18n("Run Dialog K4"), "launch", CTRL + SHIFT  + TQt::Key_R,
-                           TQT_TQOBJECT(this), TQT_SLOT(runForm4()), actionCollection(), "run4");
-  b->setToolTip(i18n("Executes dialog in KDE4"));
-  b->setWhatsThis(whatsThisFrom("Run|Run dialog"));
-  connect(this, TQT_SIGNAL(hasActiveForm(bool)), b, TQT_SLOT(setEnabled(bool)));
-  b->plug(menu);
 }
 
 void MainWindow::setupWindowActions()
@@ -798,7 +786,7 @@ void MainWindow::fileCreateTemplate()
 
 void MainWindow::createNewTemplate()
 {
-  CreateTemplate *dia = (CreateTemplate *) TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent();
+  CreateTemplate *dia = (CreateTemplate *) sender()->parent();
   TQString fn = dia->editName->text();
   TQString cn = dia->listClass->currentText();
   if (fn.isEmpty() || cn.isEmpty())
@@ -808,7 +796,7 @@ void MainWindow::createNewTemplate()
   }
 
   TQStringList templRoots;
-  const char *qtdir = getenv("QTDIR");
+  const char *qtdir = getenv("TQTDIR");
   if (qtdir)
     templRoots << qtdir;
 #ifdef TQT_INSTALL_PREFIX
