@@ -720,7 +720,7 @@ void Workspace::rmbClicked( TQListViewItem *i, const TQPoint& pos )
 bool Workspace::eventFilter( TQObject *o, TQEvent * e )
 {
     // Reggie, on what type of events do we have to execute updateBufferEdit()
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(bufferEdit) && e->type() != TQEvent::ChildRemoved )
+    if ( o == bufferEdit && e->type() != TQEvent::ChildRemoved )
   updateBufferEdit();
     return TQListView::eventFilter( o, e );
 }
