@@ -827,7 +827,7 @@ void KommanderFactory::setProperty( TQObject* obj, const TQString &prop, const T
     }
 
     if ( prop == "geometry" ) {
-	if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(toplevel) ) {
+	if ( obj == toplevel ) {
 	    toplevel->resize( v.toRect().size() );
 	    return;
 	}
@@ -1097,7 +1097,7 @@ void KommanderFactory::loadConnections( const TQDomElement &e, TQObject *connect
 		TQStrList slotList = receiver->metaObject()->slotNames( true );
 
 		// if this is a connection to a custom slot and we have a connector, try this as receiver
-		if ( slotList.find( conn.slot ) == -1 && TQT_BASE_OBJECT(receiver) == TQT_BASE_OBJECT(toplevel) && connector ) {
+		if ( slotList.find( conn.slot ) == -1 && receiver == toplevel && connector ) {
 		    slotList = connector->metaObject()->slotNames( true );
 		    receiver = connector;
 		}
