@@ -42,7 +42,10 @@
 #include <kdebug.h>
 #include <tdeglobalsettings.h>
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #ifdef TQ_WS_X11
 #include <X11/X.h>
 #include <X11/Xlib.h>
@@ -122,7 +125,7 @@ void KDockMainWindow::setMainDockWidget( KDockWidget* mdw )
 void KDockMainWindow::setView( TQWidget *view )
 {
   if ( view->isA("KDockWidget") ){
-    if ( TQT_BASE_OBJECT(view->parent()) != TQT_BASE_OBJECT(this) ) ((KDockWidget*)view)->applyToWidget( this );
+    if ( view->parent() != this ) ((KDockWidget*)view)->applyToWidget( this );
   }
 
 #ifndef NO_KDE2
@@ -779,7 +782,7 @@ void KDockWidget::updateHeader()
       setCursor(TQCursor(ArrowCursor));
 #endif
 
-    if ( (TQT_BASE_OBJECT(parent()) == TQT_BASE_OBJECT(manager->main)) || isGroup || (eDocking == KDockWidget::DockNone) ){
+    if ( (parent() == manager->main) || isGroup || (eDocking == KDockWidget::DockNone) ){
       header->hide();
     } else {
       header->setTopLevel( false );
@@ -800,7 +803,7 @@ void KDockWidget::updateHeader()
 
 void KDockWidget::applyToWidget( TQWidget* s, const TQPoint& p )
 {
-  if ( TQT_BASE_OBJECT(parent()) != TQT_BASE_OBJECT(s) )
+  if ( parent() != s )
   {
     hide();
     reparent(s, 0, TQPoint(0,0), false);
@@ -1149,7 +1152,7 @@ KDockWidget* KDockWidget::manualDock( KDockWidget* target, DockPosition dockPos,
 
     panner->setOpaqueResize(manager->splitterOpaqueResize());
     panner->setKeepSize(manager->splitterKeepSize());
-    panner->setFocusPolicy( TQ_NoFocus );
+    panner->setFocusPolicy( TQWidget::NoFocus );
     target->applyToWidget( panner );
     applyToWidget( panner );
     target->formerDockPos = target->currentDockPos;
@@ -1430,7 +1433,7 @@ void KDockWidget::setWidget( TQWidget* mw )
 {
   if ( !mw ) return;
 
-  if ( TQT_BASE_OBJECT(mw->parent()) != TQT_BASE_OBJECT(this) ){
+  if ( mw->parent() != this ){
     mw->reparent(this, 0, TQPoint(0,0), false);
   }
 
@@ -1486,13 +1489,13 @@ void KDockWidget::setDockTabName( KDockTabGroup* tab )
 
 bool KDockWidget::mayBeHide() const
 {
-  bool f = (TQT_BASE_OBJECT(parent()) != TQT_BASE_OBJECT(manager->main));
+  bool f = (parent() != manager->main);
   return ( !isGroup && !isTabGroup && f && isVisible() && ( eDocking != (int)KDockWidget::DockNone ) );
 }
 
 bool KDockWidget::mayBeShow() const
 {
-  bool f = (TQT_BASE_OBJECT(parent()) != TQT_BASE_OBJECT(manager->main));
+  bool f = (parent() != manager->main);
   return ( !isGroup && !isTabGroup && f && !isVisible() );
 }
 
@@ -2159,7 +2162,7 @@ void KDockManager::writeConfig(TQDomElement &base)
     TQObjectListIt it(*childDock);
     KDockWidget *obj1;
     while ( (obj1=(KDockWidget*)it.current()) ) {
-        if ( TQT_BASE_OBJECT(obj1->parent()) == TQT_BASE_OBJECT(main) )
+        if ( obj1->parent() == main )
             mainWidgetStr = TQString::fromLatin1(obj1->name());
         nList.append(obj1->name());
         ++it;
@@ -2494,7 +2497,7 @@ void KDockManager::writeConfig( TDEConfig* c, TQString group )
     ++it;
     //debug("  +Add subdock %s", obj->name());
     nList.append( obj->name() );
-    if ( TQT_BASE_OBJECT(obj->parent()) == TQT_BASE_OBJECT(main) )
+    if ( obj->parent() == main )
       c->writeEntry( "Main:view", obj->name() );
   }
 
