@@ -58,7 +58,7 @@ KMdiChildArea::KMdiChildArea( TQWidget *parent )
 	m_captionInactiveForeColor = TDEGlobalSettings::inactiveTextColor();
 	m_pZ = new TQPtrList<KMdiChildFrm>;
 	m_pZ->setAutoDelete( true );
-	setFocusPolicy( TQ_ClickFocus );
+	setFocusPolicy( TQWidget::ClickFocus );
 	m_defaultChildFrmSize = TQSize( 400, 300 );
 }
 
@@ -112,7 +112,7 @@ void KMdiChildArea::destroyChild( KMdiChildFrm *child, bool focusTop )
 	bool wasMaximized = ( child->state() == KMdiChildFrm::Maximized );
 
 	// destroy the old one
-	TQT_BASE_OBJECT_NAME::disconnect( child );
+	TQObject::disconnect( child );
 	child->blockSignals( true );
 	m_pZ->setAutoDelete( false );
 	m_pZ->removeRef( child );
@@ -144,7 +144,7 @@ void KMdiChildArea::destroyChildButNotItsView( KMdiChildFrm* child, bool focusTo
 	bool wasMaximized = ( child->state() == KMdiChildFrm::Maximized );
 
 	// destroy the old one
-	TQT_BASE_OBJECT_NAME::disconnect( child );
+	TQObject::disconnect( child );
 	child->unsetClient();
 	m_pZ->setAutoDelete( false );
 	m_pZ->removeRef( child );
@@ -218,12 +218,8 @@ void KMdiChildArea::setTopChild( KMdiChildFrm* child, bool /* bSetFocus */ )
 		else
 			child->raise();
 		
-#ifdef USE_QT4
-		child->m_pClient->setFocus();
-#else // USE_QT4
 		TQFocusEvent::setReason( TQFocusEvent::Other );
 		child->m_pClient->setFocus();
-#endif // USE_QT4
 	}
 }
 
