@@ -109,7 +109,7 @@ class KMDI_EXPORT KMdiChildView : public TQWidget
 {
 	friend class KMdiMainFrm;
 	friend class KMdiChildFrm;
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	// attributes
