@@ -485,15 +485,15 @@ void QuantaInit::initView()
   m_quanta->scriptTab = new ScriptTreeView(m_quanta, "Scripts");
 
   m_quanta->m_messageOutput = new MessageOutput(m_quanta, "Messages");
-  m_quanta->m_messageOutput->setFocusPolicy(TQ_NoFocus);
+  m_quanta->m_messageOutput->setFocusPolicy(TQWidget::NoFocus);
   m_quanta->m_messageOutput->showMessage(i18n("Message Window..."));
   connect(m_quanta, TQT_SIGNAL(showMessage(const TQString&, bool)), m_quanta->m_messageOutput, TQT_SLOT(showMessage(const TQString&, bool)));
   connect(m_quanta, TQT_SIGNAL(clearMessages()), m_quanta->m_messageOutput, TQT_SLOT(clear()));
 
   m_quanta->m_problemOutput = new MessageOutput(m_quanta, "Problems");
-  m_quanta->m_problemOutput->setFocusPolicy(TQ_NoFocus);
+  m_quanta->m_problemOutput->setFocusPolicy(TQWidget::NoFocus);
   m_quanta->m_annotationOutput = new AnnotationOutput(m_quanta, "Annotations");
-  m_quanta->m_annotationOutput->setFocusPolicy(TQ_NoFocus);
+  m_quanta->m_annotationOutput->setFocusPolicy(TQWidget::NoFocus);
 
   m_quanta->createPreviewPart();
   m_quanta->createDocPart();
