@@ -12,6 +12,10 @@
  *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 //qt includes
 #include <tqdir.h>
 
@@ -138,7 +142,7 @@ void ViewManager::createNewDocument()
      popupIf->installPopup((TQPopupMenu *)quantaApp->factory()->container("popup_editor", quantaApp));
 
   quantaApp->setFocusProxy(w->view());
-  w->view()->setFocusPolicy(TQ_WheelFocus);
+  w->view()->setFocusPolicy(TQWidget::WheelFocus);
   connect( v, TQT_SIGNAL(newStatus()), quantaApp, TQT_SLOT(slotNewStatus()));
 
   quantaApp->slotNewPart(doc, true);  // register new part in partmanager and make active
